@@ -15,6 +15,9 @@
 package org.mortbay.jetty;
 
 import java.io.IOException;
+import java.io.UnsupportedEncodingException;
+import java.io.Writer;
+import java.net.URLEncoder;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
@@ -35,16 +38,14 @@ import javax.servlet.http.Cookie;
 
 import org.mortbay.io.Buffer;
 import org.mortbay.io.BufferCache;
-import org.mortbay.io.BufferDateCache;
 import org.mortbay.io.BufferUtil;
 import org.mortbay.io.ByteArrayBuffer;
 import org.mortbay.io.View;
-import org.mortbay.io.BufferCache.CachedBuffer;
+import org.mortbay.util.DateCache;
 import org.mortbay.util.LazyList;
 import org.mortbay.util.QuotedStringTokenizer;
 import org.mortbay.util.StringMap;
 import org.mortbay.util.StringUtil;
-import org.mortbay.util.URIUtil;
 
 /* ------------------------------------------------------------ */
 /**
@@ -160,7 +161,7 @@ public class HttpFields
 
     /* -------------------------------------------------------------- */
     private static TimeZone __GMT = TimeZone.getTimeZone("GMT");
-    public final static BufferDateCache __dateCache = new BufferDateCache("EEE, dd MMM yyyy HH:mm:ss 'GMT'", Locale.US);
+    public final static DateCache __dateCache = new DateCache("EEE, dd MMM yyyy HH:mm:ss 'GMT'", Locale.US);
 
     /* ------------------------------------------------------------ */
     private final static String __dateReceiveFmt[] =
@@ -216,7 +217,6 @@ public class HttpFields
      */
     public Enumeration getFieldNames()
     {
-        final int revision=_revision;
         return new Enumeration()
         {
             int i = 0;
@@ -228,7 +228,7 @@ public class HttpFields
                 while (i < _fields.size())
                 {
                     Field f = (Field) _fields.get(i++);
-                    if (f != null && f._prev == null && f._revision == revision)
+                    if (f != null && f._prev == null && f._revision == _revision)
                     {
                         field = f;
                         return true;
@@ -241,7 +241,7 @@ public class HttpFields
             {
                 if (field != null || hasMoreElements())
                 {
-                    String n = BufferUtil.to8859_1_String(field._name);
+                    String n = field._name.toString();
                     field = null;
                     return n;
                 }
@@ -256,7 +256,6 @@ public class HttpFields
      */
     public Iterator getFields()
     {
-        final int revision=_revision;
         return new Iterator()
         {
             int i = 0;
@@ -268,7 +267,7 @@ public class HttpFields
                 while (i < _fields.size())
                 {
                     Field f = (Field) _fields.get(i++);
-                    if (f != null && f._revision == revision)
+                    if (f != null && f._revision == _revision)
                     {
                         field = f;
                         return true;
@@ -345,8 +344,7 @@ public class HttpFields
     {
         // TODO - really reuse strings from previous requests!
         Field field = getField(name);
-        if (field != null && field._revision == _revision) 
-            return BufferUtil.to8859_1_String(field._value);
+        if (field != null && field._revision == _revision) return field._value.toString();
         return null;
     }
 
@@ -359,8 +357,7 @@ public class HttpFields
     public Buffer get(Buffer name)
     {
         Field field = getField(name);
-        if (field != null && field._revision == _revision) 
-            return field._value;
+        if (field != null && field._revision == _revision) return field._value;
         return null;
     }
 
@@ -374,9 +371,7 @@ public class HttpFields
     public Enumeration getValues(String name)
     {
         final Field field = getField(name);
-        if (field == null) 
-            return null;
-        final int revision=_revision;
+        if (field == null) return null;
 
         return new Enumeration()
         {
@@ -384,7 +379,7 @@ public class HttpFields
 
             public boolean hasMoreElements()
             {
-                while (f != null && f._revision != revision)
+                while (f != null && f._revision != _revision)
                     f = f._next;
                 return f != null;
             }
@@ -395,7 +390,7 @@ public class HttpFields
                 Field n = f;
                 do
                     f = f._next;
-                while (f != null && f._revision != revision);
+                while (f != null && f._revision != _revision);
                 return n.getValue();
             }
         };
@@ -411,9 +406,8 @@ public class HttpFields
     public Enumeration getValues(Buffer name)
     {
         final Field field = getField(name);
-        if (field == null) 
-            return null;
-        final int revision=_revision;
+
+        if (field == null) return null;
 
         return new Enumeration()
         {
@@ -421,7 +415,7 @@ public class HttpFields
 
             public boolean hasMoreElements()
             {
-                while (f != null && f._revision != revision)
+                while (f != null && f._revision != _revision)
                     f = f._next;
                 return f != null;
             }
@@ -431,7 +425,7 @@ public class HttpFields
                 if (f == null) throw new NoSuchElementException();
                 Field n = f;
                 f = f._next;
-                while (f != null && f._revision != revision)
+                while (f != null && f._revision != _revision)
                     f = f._next;
                 return n.getValue();
             }
@@ -451,8 +445,7 @@ public class HttpFields
     public Enumeration getValues(String name, final String separators)
     {
         final Enumeration e = getValues(name);
-        if (e == null) 
-            return null;
+        if (e == null) return null;
         return new Enumeration()
         {
             QuotedStringTokenizer tok = null;
@@ -527,9 +520,8 @@ public class HttpFields
      * 
      * @param name the name of the field
      * @param value the value of the field. If null the field is cleared.
-     * @param numValue the numeric value of the field (must match value) or -1
      */
-    public void put(Buffer name, Buffer value, long numValue)
+    private void put(Buffer name, Buffer value, long numValue)
     {
         if (value == null)
         {
@@ -751,7 +743,7 @@ public class HttpFields
 
         if (field._numValue != -1) return field._numValue;
 
-        String val = valueParameters(BufferUtil.to8859_1_String(field._value), null);
+        String val = valueParameters(field._value.toString(), null);
         if (val == null) return -1;
 
         
@@ -962,32 +954,46 @@ public class HttpFields
         String name_value_params = null;
         synchronized (buf)
         {
-            QuotedStringTokenizer.quoteIfNeeded(buf, name);
+            buf.append(name);
             buf.append('=');
             if (value != null && value.length() > 0)
-                QuotedStringTokenizer.quoteIfNeeded(buf, value);
+            {
+                if (version == 0)
+                {
+                    try
+                    {
+                        buf.append(URLEncoder.encode(value, StringUtil.__ISO_8859_1));
+                    }
+                    catch (UnsupportedEncodingException e)
+                    {
+                        e.printStackTrace();
+                    }
+                }
+                else
+                    QuotedStringTokenizer.quote(buf, value);
+            }
 
             if (version > 0)
             {
-                buf.append(";Version=");
+                buf.append(";version=");
                 buf.append(version);
                 String comment = cookie.getComment();
                 if (comment != null && comment.length() > 0)
                 {
                     buf.append(";Comment=");
-                    QuotedStringTokenizer.quoteIfNeeded(buf, comment);
+                    QuotedStringTokenizer.quote(buf, comment);
                 }
             }
             String path = cookie.getPath();
             if (path != null && path.length() > 0)
             {
-                buf.append(";Path=");
-                buf.append(URIUtil.encodePath(path));
+                buf.append(";path=");
+                buf.append(path);
             }
             String domain = cookie.getDomain();
             if (domain != null && domain.length() > 0)
             {
-                buf.append(";Domain=");
+                buf.append(";domain=");
                 buf.append(domain.toLowerCase());// lowercase for IE
             }
 
@@ -996,7 +1002,7 @@ public class HttpFields
             {
                 if (version == 0)
                 {
-                    buf.append(";Expires=");
+                    buf.append(";expires=");
                     if (maxAge == 0)
                         buf.append(__01Jan1970);
                     else
@@ -1004,21 +1010,20 @@ public class HttpFields
                 }
                 else
                 {
-                    buf.append(";Max-Age=");
+                    buf.append(";max-age=");
                     buf.append(maxAge);
                 }
             }
             else if (version > 0)
             {
-                buf.append(";Discard");
+                buf.append(";discard");
             }
 
             if (cookie.getSecure())
             {
                 buf.append(";Secure");
             }
-            if (cookie instanceof HttpOnlyCookie)
-                buf.append(";HttpOnly");
+            if (cookie instanceof HttpOnlyCookie) buf.append(";HttpOnly");
 
             // TODO - straight to Buffer?
             name_value_params = buf.toString();
@@ -1027,6 +1032,20 @@ public class HttpFields
         add(HttpHeaders.SET_COOKIE_BUFFER, new ByteArrayBuffer(name_value_params));
     }
 
+    /* -------------------------------------------------------------- */
+    public void write(Writer writer) throws IOException
+    {
+        synchronized (writer)
+        {
+            for (int i = 0; i < _fields.size(); i++)
+            {
+                Field field = (Field) _fields.get(i);
+                if (field != null && field._revision == _revision) field.write(writer);
+            }
+            writer.write(StringUtil.CRLF);
+        }
+    }
+
     /* -------------------------------------------------------------- */
     public void put(Buffer buffer) throws IOException
     {
@@ -1045,7 +1064,7 @@ public class HttpFields
         {
             ByteArrayBuffer buffer = new ByteArrayBuffer(4096);
             put(buffer);
-            return BufferUtil.to8859_1_String(buffer);
+            return buffer.toString();
         }
         catch (Exception e)
         {
@@ -1353,65 +1372,30 @@ public class HttpFields
                 }
             }
         }
-        
-        
+
+        /* ------------------------------------------------------------ */
+        public void write(Writer writer) throws IOException
+        {
+            writer.write(_name.toString());
+            writer.write(":");
+            writer.write(_value.toString());
+            writer.write(StringUtil.CRLF);
+        }
 
         /* ------------------------------------------------------------ */
         public void put(Buffer buffer) throws IOException
         {
-            int o=(_name instanceof CachedBuffer)?((CachedBuffer)_name).getOrdinal():-1;
-            if (o>=0)
-                buffer.put(_name);
-            else
-            {
-                int s=_name.getIndex();
-                int e=_name.putIndex();
-                while (s<e)
-                {
-                    byte b=_name.peek(s++);
-                    switch(b)
-                    {
-                        case '\r':
-                        case '\n':
-                        case ':' :
-                            continue;
-                        default:
-                            buffer.put(b);
-                    }
-                }
-            }
-            
+            buffer.put(_name);
             buffer.put((byte) ':');
             buffer.put((byte) ' ');
-            
-            o=(_value instanceof CachedBuffer)?((CachedBuffer)_value).getOrdinal():-1;
-            if (o>=0 || _numValue>=0)
-                buffer.put(_value);
-            else
-            {
-                int s=_value.getIndex();
-                int e=_value.putIndex();
-                while (s<e)
-                {
-                    byte b=_value.peek(s++);
-                    switch(b)
-                    {
-                        case '\r':
-                        case '\n':
-                            continue;
-                        default:
-                            buffer.put(b);
-                    }
-                }
-            }
-
+            buffer.put(_value);
             BufferUtil.putCRLF(buffer);
         }
 
         /* ------------------------------------------------------------ */
         public String getName()
         {
-            return BufferUtil.to8859_1_String(_name);
+            return _name.toString();
         }
 
         /* ------------------------------------------------------------ */
@@ -1430,7 +1414,7 @@ public class HttpFields
         public String getValue()
         {
             if (_stringValue==null)
-                _stringValue=BufferUtil.to8859_1_String(_value);
+                _stringValue=_value.toString();
             return _stringValue;
         }
 
