@@ -1,5 +1,5 @@
 // ========================================================================
-// Copyright 2004-2005 Mort Bay Consulting Pty. Ltd.
+// Copyright 2004-2008 Mort Bay Consulting Pty. Ltd.
 // ------------------------------------------------------------------------
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -27,13 +27,12 @@ import javax.servlet.ServletException;
 
 import org.mortbay.component.Container;
 import org.mortbay.component.LifeCycle;
-import org.mortbay.component.Container.Relationship;
 import org.mortbay.jetty.bio.SocketConnector;
 import org.mortbay.jetty.handler.HandlerCollection;
 import org.mortbay.jetty.handler.HandlerWrapper;
 import org.mortbay.jetty.security.UserRealm;
 import org.mortbay.log.Log;
-import org.mortbay.thread.BoundedThreadPool;
+import org.mortbay.thread.QueuedThreadPool;
 import org.mortbay.thread.ThreadPool;
 import org.mortbay.util.Attributes;
 import org.mortbay.util.AttributesMap;
@@ -52,17 +51,20 @@ import org.mortbay.util.MultiException;
 public class Server extends HandlerWrapper implements Attributes
 {
     private static ShutdownHookThread hookThread = new ShutdownHookThread();
-    
+    private static String _version = (Server.class.getPackage()!=null && Server.class.getPackage().getImplementationVersion()!=null)
+        ?Server.class.getPackage().getImplementationVersion()
+        :"6.1.x";
+
     private ThreadPool _threadPool;
     private Connector[] _connectors;
     private UserRealm[] _realms;
     private Container _container=new Container();
     private SessionIdManager _sessionIdManager;
-    private boolean _sendServerVersion = true; //send Server: header by default
+    private boolean _sendServerVersion = true; //send Server: header
+    private boolean _sendDateHeader = false; //send Date: header 
     private AttributesMap _attributes = new AttributesMap();
-    private String _version = "6.1.x";
     private List _dependentLifeCycles=new ArrayList();
-    
+    private int _graceful=0;
     
     /* ------------------------------------------------------------ */
     public Server()
@@ -83,6 +85,13 @@ public class Server extends HandlerWrapper implements Attributes
         setConnectors(new Connector[]{connector});
     }
 
+
+    /* ------------------------------------------------------------ */
+    public static String getVersion()
+    {
+        return _version;
+    }
+    
     /* ------------------------------------------------------------ */
     /**
      * @return Returns the container.
@@ -172,12 +181,15 @@ public class Server extends HandlerWrapper implements Attributes
     /* ------------------------------------------------------------ */
     protected void doStart() throws Exception
     {
-        if (this.getClass().getPackage().getImplementationVersion()!=null)
-            _version=this.getClass().getPackage().getImplementationVersion();
         Log.info("jetty-"+_version);
         HttpGenerator.setServerVersion(_version);
         MultiException mex=new MultiException();
       
+        for (int i=0;_realms !=null && i<_realms.length; i++)
+        {
+            if (_realms[i] instanceof LifeCycle)
+                ((LifeCycle)_realms[i]).start();
+        }
 
         Iterator itor = _dependentLifeCycles.iterator();
         while (itor.hasNext())
@@ -191,8 +203,8 @@ public class Server extends HandlerWrapper implements Attributes
         
         if (_threadPool==null)
         {
-            BoundedThreadPool btp=new BoundedThreadPool();
-            setThreadPool(btp);
+            QueuedThreadPool tp=new QueuedThreadPool();
+            setThreadPool(tp);
         }
         
         if (_sessionIdManager!=null)
@@ -233,6 +245,33 @@ public class Server extends HandlerWrapper implements Attributes
     {
         MultiException mex=new MultiException();
         
+        for (int i=0;_realms !=null && i<_realms.length; i++)
+        {
+            if (_realms[i] instanceof LifeCycle)
+                ((LifeCycle)_realms[i]).stop();
+        }
+        
+        if (_graceful>0)
+        {
+            if (_connectors!=null)
+            {
+                for (int i=_connectors.length;i-->0;)
+                {
+                    Log.info("Graceful shutdown {}",_connectors[i]);
+                    try{_connectors[i].close();}catch(Throwable e){mex.add(e);}
+                }
+            }
+            
+            Handler[] contexts = getChildHandlersByClass(Graceful.class);
+            for (int c=0;c<contexts.length;c++)
+            {
+                Graceful context=(Graceful)contexts[c];
+                Log.info("Graceful shutdown {}",context);
+                context.setShutdown(true);
+            }
+            Thread.sleep(_graceful);
+        }
+        
         if (_connectors!=null)
         {
             for (int i=_connectors.length;i-->0;)
@@ -253,7 +292,7 @@ public class Server extends HandlerWrapper implements Attributes
         
         if (!_dependentLifeCycles.isEmpty())
         {
-            ListIterator itor = _dependentLifeCycles.listIterator(_dependentLifeCycles.size()-1);
+            ListIterator itor = _dependentLifeCycles.listIterator(_dependentLifeCycles.size());
             while (itor.hasPrevious())
             {
                 try
@@ -322,6 +361,7 @@ public class Server extends HandlerWrapper implements Attributes
         setUserRealms((UserRealm[])LazyList.removeFromArray(getUserRealms(), realm));
     }
 
+    /* ------------------------------------------------------------ */
     /* ------------------------------------------------------------ */
     /**
      * @return Returns the sessionIdManager.
@@ -331,6 +371,7 @@ public class Server extends HandlerWrapper implements Attributes
         return _sessionIdManager;
     }
 
+    /* ------------------------------------------------------------ */
     /* ------------------------------------------------------------ */
     /**
      * @param sessionIdManager The sessionIdManager to set.
@@ -354,9 +395,18 @@ public class Server extends HandlerWrapper implements Attributes
     }
 
     /* ------------------------------------------------------------ */
-    public String getVersion()
+    /**
+     * @param sendDateHeader
+     */
+    public void setSendDateHeader(boolean sendDateHeader)
     {
-        return _version;
+        _sendDateHeader = sendDateHeader;
+    }
+
+    /* ------------------------------------------------------------ */
+    public boolean getSendDateHeader()
+    {
+        return _sendDateHeader;
     }
     
     
@@ -608,7 +658,7 @@ public class Server extends HandlerWrapper implements Attributes
      */
     public Enumeration getAttributeNames()
     {
-        return _attributes.getAttributeNames();
+        return AttributesMap.getAttributeNamesCopy(_attributes);
     }
 
     /* ------------------------------------------------------------ */
@@ -629,4 +679,36 @@ public class Server extends HandlerWrapper implements Attributes
         _attributes.setAttribute(name, attribute);
     }
 
+    /* ------------------------------------------------------------ */
+    /**
+     * @return the graceful
+     */
+    public int getGracefulShutdown()
+    {
+        return _graceful;
+    }
+
+    /* ------------------------------------------------------------ */
+    /**
+     * Set graceful shutdown timeout.  If set, the {@link #doStop()} method will not immediately stop the 
+     * server. Instead, all {@link Connector}s will be closed so that new connections will not be accepted
+     * and all handlers that implement {@link Graceful} will be put into the shutdown mode so that no new requests
+     * will be accepted, but existing requests can complete.  The server will then wait the configured timeout 
+     * before stopping.
+     * @param timeoutMS the milliseconds to wait for existing request to complete before stopping the server.
+     * 
+     */
+    public void setGracefulShutdown(int timeoutMS)
+    {
+        _graceful=timeoutMS;
+    }
+
+    /* ------------------------------------------------------------ */
+    /* A component that can be gracefully shutdown.
+     * Called by doStop if a {@link #setGracefulShutdown} period is set.
+     */
+    public interface Graceful
+    {
+        public void setShutdown(boolean shutdown);
+    }
 }
