@@ -2,7 +2,7 @@
  * JFreeChart : a free chart library for the Java(tm) platform
  * ===========================================================
  *
- * (C) Copyright 2000-2007, by Object Refinery Limited and Contributors.
+ * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
  *
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
@@ -27,11 +27,13 @@
  * ----------------------
  * BorderArrangement.java
  * ----------------------
- * (C) Copyright 2004-2007, by Object Refinery Limited.
+ * (C) Copyright 2004, 2005, by Object Refinery Limited.
  *
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   -;
  *
+ * $Id: BorderArrangement.java,v 1.14.2.1 2005/10/25 20:39:38 mungady Exp $
+ *
  * Changes:
  * --------
  * 22-Oct-2004 : Version 1 (DG);
@@ -126,7 +128,7 @@ public class BorderArrangement implements Arrangement, Serializable {
                           Graphics2D g2, 
                           RectangleConstraint constraint) {
         RectangleConstraint contentConstraint 
-                = container.toContentConstraint(constraint);
+            = container.toContentConstraint(constraint);
         Size2D contentSize = null;
         LengthConstraintType w = contentConstraint.getWidthConstraintType();
         LengthConstraintType h = contentConstraint.getHeightConstraintType();
@@ -160,12 +162,16 @@ public class BorderArrangement implements Arrangement, Serializable {
                 throw new RuntimeException("Not implemented.");  
             }
             else if (h == LengthConstraintType.RANGE) {
-                contentSize = arrangeRR(container, constraint.getWidthRange(),
-                        constraint.getHeightRange(), g2);  
+                contentSize = arrangeRR(
+                    container, constraint.getWidthRange(),
+                    constraint.getHeightRange(), g2
+                );  
             }
         }
-        return new Size2D(container.calculateTotalWidth(contentSize.getWidth()),
-                container.calculateTotalHeight(contentSize.getHeight()));
+        return new Size2D(
+            container.calculateTotalWidth(contentSize.getWidth()),
+            container.calculateTotalHeight(contentSize.getHeight())
+        );
     }
     
     /**
@@ -180,23 +186,30 @@ public class BorderArrangement implements Arrangement, Serializable {
         double[] w = new double[5];
         double[] h = new double[5];
         if (this.topBlock != null) {
-            Size2D size = this.topBlock.arrange(g2, RectangleConstraint.NONE);
+            Size2D size = this.topBlock.arrange(
+                g2, RectangleConstraint.NONE
+            );
             w[0] = size.width;
             h[0] = size.height;
         }
         if (this.bottomBlock != null) {
-            Size2D size = this.bottomBlock.arrange(g2, 
-            		RectangleConstraint.NONE);
+            Size2D size = this.bottomBlock.arrange(
+                g2, RectangleConstraint.NONE
+            );
             w[1] = size.width;
             h[1] = size.height;
         }
         if (this.leftBlock != null) {
-            Size2D size = this.leftBlock.arrange(g2, RectangleConstraint.NONE);
+            Size2D size = this.leftBlock.arrange(
+                g2, RectangleConstraint.NONE
+            );
             w[2] = size.width;
             h[2] = size.height;
        }
         if (this.rightBlock != null) {
-            Size2D size = this.rightBlock.arrange(g2, RectangleConstraint.NONE);
+            Size2D size = this.rightBlock.arrange(
+                g2, RectangleConstraint.NONE
+            );
             w[3] = size.width;
             h[3] = size.height;
         }
@@ -205,8 +218,9 @@ public class BorderArrangement implements Arrangement, Serializable {
         h[3] = h[2];
         
         if (this.centerBlock != null) {
-            Size2D size = this.centerBlock.arrange(g2, 
-            		RectangleConstraint.NONE);
+            Size2D size = this.centerBlock.arrange(
+                g2, RectangleConstraint.NONE
+            );
             w[4] = size.width;
             h[4] = size.height;
         }
@@ -214,25 +228,32 @@ public class BorderArrangement implements Arrangement, Serializable {
         double centerHeight = Math.max(h[2], Math.max(h[3], h[4]));
         double height = h[0] + h[1] + centerHeight;
         if (this.topBlock != null) {
-            this.topBlock.setBounds(new Rectangle2D.Double(0.0, 0.0, width, 
-            		h[0]));
+            this.topBlock.setBounds(
+                new Rectangle2D.Double(0.0, 0.0, width, h[0])
+            );
         }
         if (this.bottomBlock != null) {
-            this.bottomBlock.setBounds(new Rectangle2D.Double(0.0, 
-            		height - h[1], width, h[1]));
+            this.bottomBlock.setBounds(
+                new Rectangle2D.Double(0.0, height - h[1], width, h[1])
+            );
         }
         if (this.leftBlock != null) {
-            this.leftBlock.setBounds(new Rectangle2D.Double(0.0, h[0], w[2], 
-            		centerHeight));
+            this.leftBlock.setBounds(
+                new Rectangle2D.Double(0.0, h[0], w[2], centerHeight)
+            );
         }
         if (this.rightBlock != null) {
-            this.rightBlock.setBounds(new Rectangle2D.Double(width - w[3], 
-            		h[0], w[3], centerHeight));
+            this.rightBlock.setBounds(
+                new Rectangle2D.Double(width - w[3], h[0], w[3], centerHeight)
+            );
         }
         
         if (this.centerBlock != null) {
-            this.centerBlock.setBounds(new Rectangle2D.Double(w[2], h[0], 
-            		width - w[2] - w[3], centerHeight));
+            this.centerBlock.setBounds(
+                new Rectangle2D.Double(
+                    w[2], h[0], width - w[2] - w[3], centerHeight
+                )
+            );
         }
         return new Size2D(width, height);
     }
@@ -273,9 +294,10 @@ public class BorderArrangement implements Arrangement, Serializable {
                                double width) {
         double[] w = new double[5];
         double[] h = new double[5];
-        RectangleConstraint c1 = new RectangleConstraint(width, null, 
-        		LengthConstraintType.FIXED, 0.0, null, 
-        		LengthConstraintType.NONE);
+        RectangleConstraint c1 = new RectangleConstraint(
+            width, null, LengthConstraintType.FIXED,
+            0.0, null, LengthConstraintType.NONE
+        );
         if (this.topBlock != null) {
             Size2D size = this.topBlock.arrange(g2, c1);
             w[0] = size.width;
@@ -286,9 +308,10 @@ public class BorderArrangement implements Arrangement, Serializable {
             w[1] = size.width;
             h[1] = size.height;
         }
-        RectangleConstraint c2 = new RectangleConstraint(0.0, 
-        		new Range(0.0, width), LengthConstraintType.RANGE, 
-        		0.0, null, LengthConstraintType.NONE);
+        RectangleConstraint c2 = new RectangleConstraint(
+            0.0, new Range(0.0, width), LengthConstraintType.RANGE,
+            0.0, null, LengthConstraintType.NONE
+        );
         if (this.leftBlock != null) {
             Size2D size = this.leftBlock.arrange(g2, c2);
             w[2] = size.width;
@@ -296,10 +319,11 @@ public class BorderArrangement implements Arrangement, Serializable {
         }
         if (this.rightBlock != null) {
             double maxW = Math.max(width - w[2], 0.0);
-            RectangleConstraint c3 = new RectangleConstraint(0.0, 
-            		new Range(Math.min(w[2], maxW), maxW), 
-            		LengthConstraintType.RANGE, 0.0, null, 
-            		LengthConstraintType.NONE);    
+            RectangleConstraint c3 = new RectangleConstraint(
+                0.0, new Range(Math.min(w[2], maxW), maxW), 
+                LengthConstraintType.RANGE,
+                0.0, null, LengthConstraintType.NONE
+            );    
             Size2D size = this.rightBlock.arrange(g2, c3);
             w[3] = size.width;
             h[3] = size.height;
@@ -309,9 +333,10 @@ public class BorderArrangement implements Arrangement, Serializable {
         h[3] = h[2];
         
         if (this.centerBlock != null) {
-            RectangleConstraint c4 = new RectangleConstraint(width - w[2] 
-                    - w[3], null, LengthConstraintType.FIXED, 0.0, null, 
-                    LengthConstraintType.NONE);    
+            RectangleConstraint c4 = new RectangleConstraint(
+                width - w[2] - w[3], null, LengthConstraintType.FIXED,
+                0.0, null, LengthConstraintType.NONE
+            );    
             Size2D size = this.centerBlock.arrange(g2, c4);
             w[4] = size.width;
             h[4] = size.height;
@@ -337,32 +362,36 @@ public class BorderArrangement implements Arrangement, Serializable {
         double[] w = new double[5];
         double[] h = new double[5];
         if (this.topBlock != null) {
-            RectangleConstraint c1 = new RectangleConstraint(widthRange, 
-            		heightRange);
+            RectangleConstraint c1 = new RectangleConstraint(
+                widthRange, heightRange
+            );
             Size2D size = this.topBlock.arrange(g2, c1);
             w[0] = size.width;
             h[0] = size.height;
         }
         if (this.bottomBlock != null) {
             Range heightRange2 = Range.shift(heightRange, -h[0], false);
-            RectangleConstraint c2 = new RectangleConstraint(widthRange, 
-            		heightRange2);  
+            RectangleConstraint c2 = new RectangleConstraint(
+                widthRange, heightRange2
+            );  
             Size2D size = this.bottomBlock.arrange(g2, c2);
             w[1] = size.width;
             h[1] = size.height;
         }
         Range heightRange3 = Range.shift(heightRange, -(h[0] + h[1]));
         if (this.leftBlock != null) {
-            RectangleConstraint c3 = new RectangleConstraint(widthRange, 
-            		heightRange3);
+            RectangleConstraint c3 = new RectangleConstraint(
+                widthRange, heightRange3
+            );
             Size2D size = this.leftBlock.arrange(g2, c3);
             w[2] = size.width;
             h[2] = size.height;
         }
         Range widthRange2 = Range.shift(widthRange, -w[2], false);
         if (this.rightBlock != null) {
-            RectangleConstraint c4 = new RectangleConstraint(widthRange2, 
-            		heightRange3);
+            RectangleConstraint c4 = new RectangleConstraint(
+                widthRange2, heightRange3
+            );
             Size2D size = this.rightBlock.arrange(g2, c4);
             w[3] = size.width;
             h[3] = size.height;
@@ -372,8 +401,9 @@ public class BorderArrangement implements Arrangement, Serializable {
         h[3] = h[2];
         Range widthRange3 = Range.shift(widthRange, -(w[2] + w[3]), false);
         if (this.centerBlock != null) {
-            RectangleConstraint c5 = new RectangleConstraint(widthRange3, 
-            		heightRange3);
+            RectangleConstraint c5 = new RectangleConstraint(
+                widthRange3, heightRange3
+            );
             // TODO:  the width and height ranges should be reduced by the 
             // height required for the top and bottom, and the width required
             // by the left and right 
@@ -384,25 +414,32 @@ public class BorderArrangement implements Arrangement, Serializable {
         double width = Math.max(w[0], Math.max(w[1], w[2] + w[4] + w[3]));
         double height = h[0] + h[1] + Math.max(h[2], Math.max(h[3], h[4]));
         if (this.topBlock != null) {
-            this.topBlock.setBounds(new Rectangle2D.Double(0.0, 0.0, width, 
-            		h[0]));
+            this.topBlock.setBounds(
+                new Rectangle2D.Double(0.0, 0.0, width, h[0])
+            );
         }
         if (this.bottomBlock != null) {
-            this.bottomBlock.setBounds(new Rectangle2D.Double(0.0, 
-            		height - h[1], width, h[1]));
+            this.bottomBlock.setBounds(
+                new Rectangle2D.Double(0.0, height - h[1], width, h[1])
+            );
         }
         if (this.leftBlock != null) {
-            this.leftBlock.setBounds(new Rectangle2D.Double(0.0, h[0], w[2], 
-            		h[2]));
+            this.leftBlock.setBounds(
+                new Rectangle2D.Double(0.0, h[0], w[2], h[2])
+            );
         }
         if (this.rightBlock != null) {
-            this.rightBlock.setBounds(new Rectangle2D.Double(width - w[3], 
-            		h[0], w[3], h[3]));
+            this.rightBlock.setBounds(
+                new Rectangle2D.Double(width - w[3], h[0], w[3], h[3])
+            );
         }
         
         if (this.centerBlock != null) {
-            this.centerBlock.setBounds(new Rectangle2D.Double(w[2], h[0], 
-            		width - w[2] - w[3], height - h[0] - h[1]));
+            this.centerBlock.setBounds(
+                new Rectangle2D.Double(
+                    w[2], h[0], width - w[2] - w[3], height - h[0] - h[1]
+                )
+            );
         }
         return new Size2D(width, height);
     }
@@ -422,36 +459,41 @@ public class BorderArrangement implements Arrangement, Serializable {
         double[] h = new double[5];
         w[0] = constraint.getWidth();
         if (this.topBlock != null) {
-            RectangleConstraint c1 = new RectangleConstraint(w[0], null, 
-            		LengthConstraintType.FIXED, 0.0, 
-            		new Range(0.0, constraint.getHeight()), 
-            		LengthConstraintType.RANGE);
+            RectangleConstraint c1 = new RectangleConstraint(
+                w[0], null, LengthConstraintType.FIXED,
+                0.0, new Range(0.0, constraint.getHeight()), 
+                LengthConstraintType.RANGE
+            );
             Size2D size = this.topBlock.arrange(g2, c1);
             h[0] = size.height;
         }
         w[1] = w[0];
         if (this.bottomBlock != null) {
-            RectangleConstraint c2 = new RectangleConstraint(w[0], null, 
-            		LengthConstraintType.FIXED, 0.0, new Range(0.0, 
-            		constraint.getHeight() - h[0]), LengthConstraintType.RANGE);
+            RectangleConstraint c2 = new RectangleConstraint(
+                w[0], null, LengthConstraintType.FIXED,
+                0.0, new Range(0.0, constraint.getHeight() - h[0]), 
+                LengthConstraintType.RANGE
+            );
             Size2D size = this.bottomBlock.arrange(g2, c2);
             h[1] = size.height;
         }
         h[2] = constraint.getHeight() - h[1] - h[0];
         if (this.leftBlock != null) {
-            RectangleConstraint c3 = new RectangleConstraint(0.0, 
-            		new Range(0.0, constraint.getWidth()), 
-            		LengthConstraintType.RANGE, h[2], null, 
-            		LengthConstraintType.FIXED);
+            RectangleConstraint c3 = new RectangleConstraint(
+                0.0, new Range(0.0, constraint.getWidth()), 
+                LengthConstraintType.RANGE,
+                h[2], null, LengthConstraintType.FIXED
+            );
             Size2D size = this.leftBlock.arrange(g2, c3);
             w[2] = size.width;            
         }
         h[3] = h[2];
         if (this.rightBlock != null) {
-            RectangleConstraint c4 = new RectangleConstraint(0.0, 
-            		new Range(0.0, constraint.getWidth() - w[2]), 
-            		LengthConstraintType.RANGE, h[2], null, 
-            		LengthConstraintType.FIXED);
+            RectangleConstraint c4 = new RectangleConstraint(
+                0.0, new Range(0.0, constraint.getWidth() - w[2]), 
+                LengthConstraintType.RANGE,
+                h[2], null, LengthConstraintType.FIXED
+            );
             Size2D size = this.rightBlock.arrange(g2, c4);
             w[3] = size.width;            
         }
@@ -463,24 +505,29 @@ public class BorderArrangement implements Arrangement, Serializable {
         }
        
         if (this.topBlock != null) {
-            this.topBlock.setBounds(new Rectangle2D.Double(0.0, 0.0, w[0], 
-            		h[0]));
+            this.topBlock.setBounds(
+                new Rectangle2D.Double(0.0, 0.0, w[0], h[0])
+            );
         }
         if (this.bottomBlock != null) {
-            this.bottomBlock.setBounds(new Rectangle2D.Double(0.0, h[0] + h[2],
-            		w[1], h[1]));
+            this.bottomBlock.setBounds(
+                new Rectangle2D.Double(0.0, h[0] + h[2], w[1], h[1])
+            );
         }
         if (this.leftBlock != null) {
-            this.leftBlock.setBounds(new Rectangle2D.Double(0.0, h[0], w[2], 
-            		h[2]));
+            this.leftBlock.setBounds(
+                new Rectangle2D.Double(0.0, h[0], w[2], h[2])
+            );
         }
         if (this.rightBlock != null) {
-            this.rightBlock.setBounds(new Rectangle2D.Double(w[2] + w[4], h[0],
-            		w[3], h[3]));
+            this.rightBlock.setBounds(
+                new Rectangle2D.Double(w[2] + w[4], h[0], w[3], h[3])
+            );
         }
         if (this.centerBlock != null) {
-            this.centerBlock.setBounds(new Rectangle2D.Double(w[2], h[0], w[4],
-            		h[4]));
+            this.centerBlock.setBounds(
+                new Rectangle2D.Double(w[2], h[0], w[4], h[4])
+            );
         }
         return new Size2D(constraint.getWidth(), constraint.getHeight());
     }
